% Written by Yongquan and Huixin
% August 2022
% 
% plot IRF difference for demand shock (with vs. without bailout rule, figure 7)

clear all
% close all
current_path = pwd;

% choose the comparison
% plot IRF differences under different credit rules
%   choose index_rule_norule =0/1/2/3  (run four times)
index_rule_norule = 3;
index_plot_save = 0;
index_small_panel = 1;  % small or large panel IRF

% simulations

% compare IRF diff for rhobo = 0 vs. 0.95 with distortionary tax.
if index_rule_norule==1
    cd ./dynare_code
    dynare norule_tax.mod
    irf_EME_norule = oo_.irfs;
    dynare rule_tax.mod
    irf_EME_rule = oo_.irfs;
    cd ..
% compare IRF diff for rhobogdp = 0 vs. 900 with distortionary tax.
elseif index_rule_norule==0
    cd ./dynare_code
    dynare norule_tax.mod
    irf_EME_norule = oo_.irfs;
    dynare persistrule_tax.mod
    irf_EME_rule = oo_.irfs;
    cd ..
% compare IRF diff for rhobo = 0 vs. 0.95 without distortionary tax.   
elseif index_rule_norule==2
    cd ../dynare_code
    dynare norule.mod
    irf_EME_norule = oo_.irfs;
    dynare rule.mod
    irf_EME_rule = oo_.irfs;
    cd(current_path)
% compare IRF diff for rhobogdp = 0 vs. 900 without distortionary tax.
else
    cd ../dynare_code
    dynare norule.mod
    irf_EME_norule = oo_.irfs;
    dynare persistrule.mod
    irf_EME_rule = oo_.irfs;
    cd(current_path)
end

% load steady-state values
if index_rule_norule<=1
    var_list_mod = {'Bailout','GI','C','Y','I','WG','Wp','R','T','L','Lp','LG','PG','Kp',...
    'KG','GC','Ap','At','N','B','RB','omega','z','fo','fo1','go','go1','do',...
    'bo','ppi','YF','x','gcshock','gishock','boshock','qk','tau','Y_output','YG',...
    'beta','betashock'};
else

    var_list_mod = {'Bailout','GI','C','Y','I','WG','Wp','R','T','L','Lp','LG','PG','Kp',...
    'KG','GC','Ap','At','N','B','RB','omega','z','fo','fo1','go','go1','do',...
    'bo','ppi','YF','x','gcshock','gishock','boshock','betashock','qk','tau','Y_output','YG','beta'};
end
var = strcat(var_list_mod,'_ss');

for ii = 1:length(var_list_mod)
    eval([char(var(ii)) '= oo_.steady_state(ii);'])
end

% plot IRFs
if index_small_panel == 1
    % a small panel
    var_names = {'YG','KG','I',...
        'L','C','Y_output',...
        'do','Bailout','Y'};
    var_titles = {'Infrastructure output','Public capital','Private investment',...
        'Labor','Consumption','Output',...
        'NPL ratio', 'Bailout cost','GDP'};

    figure(4); aa = 3; bb = 3; 
    i_ppi = 0; i_rb = 0;
    i_nfl = 3*2+1; i_bailout = 3*2+2;
    ix = 0;
    
else
    % a large panel
    var_names = {'LG','WG','YG',...
        'Lp','Wp','YF',...
        'KG','I','x',...
        'do','Bailout','T',...
        'Y_output','Y','C',...
        'PG','ppi','RB'};
    var_titles = {'Infrastructure labor','Infrastructure wage','Infrastructure output',...
        'Private labor','Private wage','Private output',...
        'Public capital','Private investment', 'Real marginal cost',...
        'NPL ratio', 'Bailout cost','Tax',...
        'Output','GDP', 'Consumption', ...
        'Infrastructure price','Inflation','Policy rate'};

    figure(4); aa = 6; bb = 3; 
    i_ppi = 3*5+2; i_rb = 3*6;
    i_nfl = 3*3+1; i_bailout = 3*3+2;
    ix = 3*3;
end

steps = 40;
for ii = 1:length(var_names)
    subplot(aa,bb,ii); 
    var_ii_ss = eval(char(strcat(var_names(ii),'_ss')));    

    if index_rule_norule == 1
        linecolor = 'k-.';
    elseif index_rule_norule == 0
        linecolor = 'r:';
        
    elseif index_rule_norule == 2
        linecolor = 'g-.';
    else
        linecolor = 'g:';        
    end

    var_rule_ii = char(strcat('irf_EME_rule.',var_names(ii),'_ebeta(1:steps)'));        
    var_norule_ii = char(strcat('irf_EME_norule.',var_names(ii),'_ebeta(1:steps)'));

    if (ii==i_nfl)
        plot((eval(var_rule_ii)-eval(var_norule_ii))*100, linecolor, 'LineWidth', 2); hold on;
        ylabel('percent')
        title(var_titles(ii))
    elseif ii == i_bailout
        Y_ss = eval(char(strcat('Y_ss')));
        plot((eval(var_rule_ii)-eval(var_norule_ii))/Y_ss*100, linecolor, 'LineWidth', 2); hold on;
        ylabel('percent')
        title(char(strcat(var_titles(ii),' (as share of Y_{ss})')))
    elseif ((ii == i_ppi) | (ii == i_rb))
        plot(400*(eval(var_rule_ii)-eval(var_norule_ii)), linecolor, 'LineWidth', 2); hold on;
        ylabel('percent (annual)')
        title(var_titles(ii))
    elseif (ii == ix)
        plot(-100*(eval(var_rule_ii)-eval(var_norule_ii))/var_ii_ss, linecolor, 'LineWidth', 2); hold on;
        ylabel('pp')
        title(var_titles(ii))
    else
        plot(100*(eval(var_rule_ii)-eval(var_norule_ii))/var_ii_ss, linecolor, 'LineWidth', 2); hold on;
        ylabel('pp')
        title(var_titles(ii))
    end            
    grid on; 
end


if index_plot_save ==1
    figure(4)
    set(gcf,'PaperPositionMode','manual')
    set(gcf,'PaperUnits','inches','PaperPosition',[0 -1 9 6])
    % left, bottom, horitonzal length, vertial length   
    print -depsc ebeta_diff_tax.eps
end

