% Written by Yongquan and Huixin
% August 2022

% plot IRF difference for demand shock (with vs. without bailout rule, figure 6)

clear all
% close all
current_path = pwd;

% choose the comparison
% plot IRF differences under different credit rules
%   choose index_rule_norule =0 /1  (run two times)
index_rule_norule = 0;
index_plot_save = 1;
index_small_panel = 0;  % small or large panel IRF

% simulations
cd ./dynare_code

% compare IRF diff for rhobo = 0 vs. 0.95
if index_rule_norule==1
    dynare norule
    irf_EME_norule = oo_.irfs;
    dynare rule
    irf_EME_rule = oo_.irfs;
% compare IRF diff for rhobogdp = 0 vs. 900
else
    dynare norule
    irf_EME_norule = oo_.irfs;
    dynare persistrule
    irf_EME_rule = oo_.irfs;
end
cd ..

% load steady-state values
var_list_mod = {'Bailout','GI','C','Y','I','WG','Wp','R','T','L','Lp','LG','PG','Kp',...
    'KG','GC','Ap','At','N','B','RB','omega','z','fo','fo1','go','go1','do',...
    'bo','ppi','YF','x','gcshock','gishock','boshock','betashock','qk','tau','Y_output','YG','beta'};


var = strcat(var_list_mod,'_ss');
for ii = 1:length(var_list_mod)
    eval([char(var(ii)) '= oo_.steady_state(ii);'])
end

% plot IRFs
if index_small_panel == 1
    % a small panel
    var_names = {'LG','WG','YG',...
    'Lp','Wp','YF',...
    'do','Bailout','T',...
    'KG','Y','C'};
    var_titles = {'Infrastructure labor','Infrastructure wage','Infrastructure output',...
    'Private labor','Private wage','Private output',...
    'NPL ratio', 'Bailout cost','Tax',...
    'Public capital','GDP', 'Consumption'};

    figure(4); aa = 4; bb = 3; 
    i_nfl = 3*2+1; i_bailout = 3*2+2;
    i_ppi = 0; i_rb = 0; ix = 0;
    
else
    % a large panel
    var_names = {'LG','WG','YG',...
        'Lp','Wp','YF',...
        'KG','I','x',...
        'do','Bailout','T',...
        'Y_output','Y','C',...
        'PG','ppi','RB'};
    var_titles = {'Infrastructure labor','Infrastructure wage','Infrastructure output',...
        'Private labor','Private wage','Private output',...
        'Public capital','Private investment', 'Real marginal cost',...
        'NPL ratio', 'Bailout cost','Tax',...
        'Output','GDP', 'Consumption', ...
        'Infrastructure price','Inflation','Policy rate'};

    figure(4); aa = 6; bb = 3; 
    i_ppi = 3*5+2; i_rb = 3*6;
    i_nfl = 3*3+1; i_bailout = 3*3+2;
    ix = 3*3;
end

steps = 40;
for ii = 1:length(var_names)
    subplot(aa,bb,ii); 
    var_ii_ss = eval(char(strcat(var_names(ii),'_ss')));    

    if index_rule_norule == 1
        linecolor = 'k--';
    else 
        linecolor = 'r:';
    end

    var_rule_ii = char(strcat('irf_EME_rule.',var_names(ii),'_ebeta(1:steps)'));        
    var_norule_ii = char(strcat('irf_EME_norule.',var_names(ii),'_ebeta(1:steps)'));

    if (ii==i_nfl)
        plot((eval(var_rule_ii)-eval(var_norule_ii))*100, linecolor, 'LineWidth', 2); hold on;
        ylabel('percent')
        title(var_titles(ii))
    elseif ii == i_bailout
        Y_ss = eval(char(strcat('Y_ss')));
        plot((eval(var_rule_ii)-eval(var_norule_ii))/Y_ss*100, linecolor, 'LineWidth', 2); hold on;
        ylabel('percent')
        title(char(strcat(var_titles(ii),' (as share of Y_{ss})')))
    elseif ((ii == i_ppi) | (ii == i_rb))
        plot(400*(eval(var_rule_ii)-eval(var_norule_ii)), linecolor, 'LineWidth', 2); hold on;
        ylabel('percent (annual)')
        title(var_titles(ii))
    elseif (ii == ix)
        plot(-100*(eval(var_rule_ii)-eval(var_norule_ii))/var_ii_ss, linecolor, 'LineWidth', 2); hold on;
        ylabel('pp')
        title(var_titles(ii))
    else
        plot(100*(eval(var_rule_ii)-eval(var_norule_ii))/var_ii_ss, linecolor, 'LineWidth', 2); hold on;
        ylabel('pp')
        title(var_titles(ii))
    end            
    grid on; 
end


if index_plot_save ==1
    figure(4)
    set(gcf,'PaperPositionMode','manual')
    set(gcf,'PaperUnits','inches','PaperPosition',[0 -1 9 12])
    % left, bottom, horitonzal length, vertial length   
    print -depsc ebeta_diff.eps
end

