% Written by Yongquan and Huixin
% August 2022

clear all
current_path = pwd;

% 
index_instrument = 3; % 1, compare multiplier across different fiscal instruments
                      % 0, compare mult across different credit rules
                      % 3, compare four cases (figure 8)
index_plot_save = 0;
                      
if index_instrument == 1
    % simulations
    cd ./dynare_code
    dynare norule.mod
    irf_EME = oo_.irfs;
    cd ..

    % load steady-state values
    var_list_mod = {'Bailout','GI','C','Y','I','WG','Wp','R','T','L','Lp','LG','PG','Kp',...
        'KG','GC','Ap','At','N','B','RB','omega','z','fo','fo1','go','go1','do',...
        'bo','ppi','YF','x','gcshock','gishock','boshock','qk','tau','Y_output','YG'};

    var = strcat(var_list_mod,'_ss');
    for ii = 1:length(var_list_mod)
        eval([char(var(ii)) '= oo_.steady_state(ii);'])
    end

    % compute multiplier
    horizon = 80;
    MultB = zeros(horizon,1);
    MultGI = zeros(horizon,1);
    MultGC = zeros(horizon,1);
%     MultBeta = zeros(horizon,1);
    for ii = 1:horizon
        MultB(ii) = PVBmultiplier(RB_ss,irf_EME,ii);
        MultGI(ii) = PVGImultiplier(RB_ss,irf_EME,ii);
        MultGC(ii) = PVGCmultiplier(RB_ss,irf_EME,ii);
    end
    figure(3);
    plot(MultB,'b', 'LineWidth', 2); hold on;
    plot(MultGI,'k-.', 'LineWidth', 2); hold on;
    plot(MultGC,'r:', 'LineWidth', 2); hold on;
%     plot(MultBeta,'g*', 'LineWidth', 2); hold on;
    legend('Credit','Govt investment','Govt consumption')  
    legend('location','southeast')
    grid on

elseif index_instrument==0
    
    % simulations
    cd ./dynare_code
    dynare norule.mod
    irf_EME_norule = oo_.irfs;
    dynare persistrule.mod
    irf_EME_persistrule = oo_.irfs;
    dynare rule.mod
    irf_EME_rule = oo_.irfs;
    cd ..

    % load steady-state values
    var_list_mod = {'Bailout','GI','C','Y','I','WG','Wp','R','T','L','Lp','LG','PG','Kp',...
        'KG','GC','Ap','At','N','B','RB','omega','z','fo','fo1','go','go1','do',...
        'bo','ppi','YF','x','gcshock','gishock','boshock','qk','tau','Y_output','YG'};

    var = strcat(var_list_mod,'_ss');
    for ii = 1:length(var_list_mod)
        eval([char(var(ii)) '= oo_.steady_state(ii);'])
    end

    % compute multiplier
    horizon = 80;
    MultBeta_rule = zeros(horizon,1);
    MultBeta_persistrule = zeros(horizon,1);
    MultB = zeros(horizon,1);
    for ii = 1:horizon
        MultBeta_rule(ii) = PVbetaMultiplier(RB_ss,irf_EME_rule,irf_EME_norule,ii);
        MultBeta_persistrule(ii) = PVbetaMultiplier(RB_ss,irf_EME_persistrule,irf_EME_norule,ii);
        MultB(ii) = PVBmultiplier(RB_ss,irf_EME_norule,ii);
    end
    figure(3);
    plot(MultBeta_rule,'k--', 'LineWidth', 2); hold on;
    plot(MultBeta_persistrule,'r:', 'LineWidth', 2); hold on;
    plot(MultB,'b', 'LineWidth', 2); hold on;
    legend('Transitory credit rule','Persistent credit rule')  
    legend('location','southeast')
    grid on
else
    % simulations
    cd ./dynare_code
    dynare norule_rhobo00.mod
    irf_EME_norule_rhobo00 = oo_.irfs;    
    dynare norule_rhobo095.mod    
    irf_EME_norule_rhobo095 = oo_.irfs;
    dynare persistrule.mod
    irf_EME_persistrule = oo_.irfs;
    dynare rule.mod
    irf_EME_rule = oo_.irfs;
    cd ..

    % load steady-state values
    var_list_mod = {'Bailout','GI','C','Y','I','WG','Wp','R','T','L','Lp','LG','PG','Kp',...
        'KG','GC','Ap','At','N','B','RB','omega','z','fo','fo1','go','go1','do',...
        'bo','ppi','YF','x','gcshock','gishock','boshock','qk','tau','Y_output','YG'};

    var = strcat(var_list_mod,'_ss');
    for ii = 1:length(var_list_mod)
        eval([char(var(ii)) '= oo_.steady_state(ii);'])
    end

    % compute multiplier
    horizon = 80;
    MultBeta_rule = zeros(horizon,1);
    MultBeta_persistrule = zeros(horizon,1);
    MultB = zeros(horizon,1);
    for ii = 1:horizon
        MultB_rule(ii)            =  PVBmultiplier(RB_ss,irf_EME_rule,ii);
        MultB_persistrule(ii)     =  PVBmultiplier(RB_ss,irf_EME_persistrule,ii);
        MultB_norule_rhobo00(ii)  =  PVBmultiplier(RB_ss,irf_EME_norule_rhobo00,ii);
        MultB_norule_rhobo095(ii) =  PVBmultiplier(RB_ss,irf_EME_norule_rhobo095,ii);
    end
    figure(3);
    plot(MultB_rule,'k', 'LineWidth', 2); hold on;
    plot(MultB_persistrule,'r', 'LineWidth', 2); hold on;    
    plot(MultB_norule_rhobo00,'k--', 'LineWidth', 2); hold on;
    plot(MultB_norule_rhobo095,'r--', 'LineWidth', 2); hold on;
    legend('Transitory credit rule','Persistent credit rule','Transitory credit shock','Persistent credit shock')  
    legend('location','southeast')
    grid on
    print -depsc mult_rule_tax.eps
end

if index_plot_save ==1
    figure(3)
    set(gcf,'PaperPositionMode','manual')
    set(gcf,'PaperUnits','inches','PaperPosition',[0 -1 6 4])
    % left, bottom, horitonzal length, vertial length   
    print -depsc mult_gc_gi_sb.eps
end
